summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/geebee.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/geebee.cpp')
-rw-r--r--src/mame/audio/geebee.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/geebee.cpp b/src/mame/audio/geebee.cpp
index 037a398dc3b..63859916d7c 100644
--- a/src/mame/audio/geebee.cpp
+++ b/src/mame/audio/geebee.cpp
@@ -42,7 +42,7 @@ void geebee_sound_device::device_start()
m_decay[0x7fff - i] = (int16_t) (0x7fff/exp(1.0*i/4096));
/* 1V = HSYNC = 18.432MHz / 3 / 2 / 384 = 8000Hz */
- m_channel = machine().sound().stream_alloc(*this, 0, 1, clock() / 3 / 2 / 384);
+ m_channel = stream_alloc_legacy(0, 1, clock() / 3 / 2 / 384);
m_vcount = 0;
m_volume_timer = timer_alloc(TIMER_VOLUME_DECAY);
@@ -103,10 +103,10 @@ void geebee_sound_device::sound_w(u8 data)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void geebee_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void geebee_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
stream_sample_t *buffer = outputs[0];
@@ -103,10 +103,10 @@ void geebee_sound_device::sound_w(u8 data)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------